betty.link module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.link module

An API for linking to web resources.

class betty.link.Link

  Bases: `ABC`

  A link to a web resource.

  abstract property label: Localizable

    The human-readable short link label.

  abstract property url: str

    The absolute URL the link points to.